Crate rustkernel[−][src]
Re-exports
Modules
This module is responsible for keeping the program in state
between API calls. The Program struct holds the cells in a
hashmap
Functions
Extracts body of request using a regex capture group and parsing the content length. Splits the request in two and takes the second block following the http 1.1 standard of a separation by two newlines